<?php
/**
 * DBクラス
 *
 * PHP versions 5
 *
 * LICENSE: This source file is licensed under the terms of the GNU General Public License.
 *
 * @package    Magic3 Framework
 * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 * @copyright  Copyright 2006-2008 Magic3 Project.
 * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
 * @version    SVN: $Id$
 * @link       http://www.magic3.org
 */
require_once($gEnvManager->getDbPath() . '/baseDb.php');

class admin_tableDb extends BaseDb
{	
	/**
	 * テーブル定義情報にフィールド追加
	 *
	 * @param string $tableName		テーブル名
	 * @param string $fieldName		フィールド名(空文字列=テーブル名保持用)
	 * @param string $dispName		項目表示名
	 * @param string $dataType		データ型
	 * @param string $defaultValue	デフォルト値
	 * @return						true = 正常、false=異常
	 */
	function addTableField($tableName, $fieldName, $dispName, $dataType, $defaultValue)
	{
		global $gEnvManager;
		
		// 引数エラーチェック
		if (empty($tableName)) return false;
		
		// トランザクション開始
		$this->startTransaction();
		
		// 追加用のインデックスNoを作成
		$index = 0;
		$queryStr  = 'SELECT max(td_index) as ms FROM _table_def ';
		$queryStr .=   'WHERE td_table_id = ? ';
		$ret = $this->selectRecord($queryStr, array($tableName), $row);
		if ($ret) $index = $row['ms'] + 1;
		
		// 新規レコード追加
		$queryStr = 'INSERT INTO _table_def ';
		$queryStr .=  '(';
		$queryStr .=  'td_table_id, ';
		$queryStr .=  'td_id, ';
		$queryStr .=  'td_index, ';
		$queryStr .=  'td_type, ';
		$queryStr .=  'td_name, ';
		$queryStr .=  'td_default_value) ';
		$queryStr .=  'VALUES ';
		$queryStr .=  '(?, ?, ?, ?, ?, ?)';
		$ret =$this->execStatement($queryStr, array($tableName, $fieldName, $index, $dataType, $dispName, $defaultValue));
			
		// トランザクション確定
		$ret = $this->endTransaction();
		return $ret;
	}
	/**
	 * テーブル定義情報の一覧を取得
	 *
	 * @param string	$tableName			テーブル名
	 * @param function	$callback			コールバック関数
	 * @return 			なし
	 */
	function getTableDef($tableName, $callback)
	{
		$queryStr = 'SELECT * FROM _table_def ';
		$queryStr .=  'WHERE td_table_id = ? ';
		$queryStr .=  'AND td_id != \'\' ';		// 空フィールド以外
		$queryStr .=  'ORDER BY td_index';
		$this->selectLoop($queryStr, array($tableName), $callback, null);
	}
	/**
	 * テーブル定義IDの一覧を取得
	 *
	 * @param function	$callback			コールバック関数
	 * @return 			なし
	 */
	function getAllTableIdList($callback)
	{
		$queryStr = 'SELECT DISTINCT td_table_id FROM _table_def ';
		$queryStr .=  'ORDER BY td_serial desc';
		$this->selectLoop($queryStr, array(), $callback, null);
	}
	/**
	 * フィールド名の存在チェック
	 *
	 * @param string  $tableName	テーブル名
	 * @param string  $fieldName	フィールド名
	 * @return bool					true=存在する、false=存在しない
	 */
	function isExistsField($tableName, $fieldName)
	{
		$queryStr = 'SELECT * FROM _table_def ';
		$queryStr .=  'WHERE td_table_id = ? ';
		$queryStr .=  'AND td_id = ? ';
		return $this->isRecordExists($queryStr, array($tableName, $fieldName));
	}
	/**
	 * 
	 *
	 * @param string  $tableName	テーブル名
	 * @param array  $rows			取得レコード
	 * @return						true=正常、false=異常
	 */
	function getTemplate($tableName, &$row)
	{
		$queryStr  = 'select * from _templates ';
		$queryStr .=   'where tm_serial = ? ';
		$ret = $this->selectRecord($queryStr, array($serial), $row);
		return $ret;
	}
}
?>
